// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KGUIADDONS_VERSION_H
#define KGUIADDONS_VERSION_H

#define KGUIADDONS_VERSION_STRING "6.23.1"
#define KGUIADDONS_VERSION_MAJOR 6
#define KGUIADDONS_VERSION_MINOR 23
#define KGUIADDONS_VERSION_PATCH 1
#define KGUIADDONS_VERSION ((6<<16)|(23<<8)|(1))

#endif
